==> haskell-th-expand-syns-0.4.9.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-expand-syns
version:              0.4.9.0
visibility:           public
id:                   th-expand-syns-0.4.9.0-HKbinnlHeuc7fqKHuua4r
key:                  th-expand-syns-0.4.9.0-HKbinnlHeuc7fqKHuua4r
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.

    As of version @0.4.9.0@, this library is a small shim on
    top of the @applySubstitution@/@resolveTypeSynonyms@
    functions from @th-abstraction@, so you may want to
    consider using @th-abstraction@ instead.

category:             Template Haskell
abi:                  88ecc92a1c6c2fc1a82c0fc52e47f8ae
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
hidden-modules:       Language.Haskell.TH.ExpandSyns.SemigroupCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/th-expand-syns-0.4.9.0
hs-libraries:         HSth-expand-syns-0.4.9.0-HKbinnlHeuc7fqKHuua4r
depends:
    base-4.15.1.0 containers-0.6.4.1 syb-0.7.2.1-IRarEg3pgAnIGKYwrA77mR
    template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-expand-syns-0.4.9.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-expand-syns
version:              0.4.9.0
visibility:           public
id:                   th-expand-syns-0.4.9.0-HCk2yO7mnXnKeaPkBAAh6u
key:                  th-expand-syns-0.4.9.0-HCk2yO7mnXnKeaPkBAAh6u
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.

    As of version @0.4.9.0@, this library is a small shim on
    top of the @applySubstitution@/@resolveTypeSynonyms@
    functions from @th-abstraction@, so you may want to
    consider using @th-abstraction@ instead.

category:             Template Haskell
abi:                  a6f98ac6bfcc04669aee2f3bc96f1eaa
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
hidden-modules:       Language.Haskell.TH.ExpandSyns.SemigroupCompat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-expand-syns-0.4.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/th-expand-syns-0.4.9.0
hs-libraries:         HSth-expand-syns-0.4.9.0-HCk2yO7mnXnKeaPkBAAh6u
depends:
    base-4.15.1.0 containers-0.6.4.1 syb-0.7.2.1-KYKaNnczqa08CQ4buLVjvA
    template-haskell-2.17.0.0
    th-abstraction-0.4.3.0-KTsBdnGbxBE1GYg4VOLAou

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
